==> flutter_control-0.98.85%2B1.tar.gz: example/c_localization_delegate/lib/settings_page.dart <==
import 'package:flutter_control/core.dart';

class SettingsPage extends ControlWidget {
  @override
  Widget build(BuildContext context) {
    return Scaffold(
      appBar: AppBar(
        title: Text(localize('settings_title')),
      ),
      body: Container(
        padding: const EdgeInsets.all(32.0),
        child: Column(
          mainAxisAlignment: MainAxisAlignment.center,
          children: <Widget>[
            Text(
              extractLocalization({
                'en': 'Hi, current localization is se to English.',
                'es': 'Hola, la localización actual es para español.',
              }),
              style: Theme.of(context).textTheme.headline6,
              textAlign: TextAlign.center,
            ),
            Padding(
              padding: const EdgeInsets.symmetric(vertical: 24.0),
              child: Row(
                mainAxisAlignment: MainAxisAlignment.spaceEvenly,
                children: <Widget>[
                  RaisedButton(
                    onPressed: () =>
                        Control.broadcaster.broadcast(Locale, Locale('en')),
                    child: Text(localize('button_en')),
                  ),
                  RaisedButton(
                    onPressed: () =>
                        Control.broadcaster.broadcast(Locale, Locale('es')),
                    child: Text(localize('button_es')),
                  ),
                ],
              ),
            ),
          ],
        ),
      ),
    );
  }
}

==> flutter_control-2.5.1%2B1.tar.gz: example/c_localization_delegate/lib/settings_page.dart <==
import 'package:flutter_control/core.dart';

class SettingsPage extends ControlWidget {
  @override
  Widget build(BuildContext context) {
    return Scaffold(
      appBar: AppBar(
        title: Text(localize('settings_title')),
      ),
      body: Container(
        padding: const EdgeInsets.all(32.0),
        child: Column(
          mainAxisAlignment: MainAxisAlignment.center,
          children: <Widget>[
            Text(
              extractLocalization({
                'en': 'Hi, current localization is se to English.',
                'es': 'Hola, la localización actual es para español.',
              }),
              style: Theme.of(context).textTheme.headline6,
              textAlign: TextAlign.center,
            ),
            Padding(
              padding: const EdgeInsets.symmetric(vertical: 24.0),
              child: Row(
                mainAxisAlignment: MainAxisAlignment.spaceEvenly,
                children: <Widget>[
                  RaisedButton(
                    onPressed: () => Control.broadcast
                        .broadcast<Locale>(value: Locale('en')),
                    child: Text(localize('button_en')),
                  ),
                  RaisedButton(
                    onPressed: () => Control.broadcast
                        .broadcast<Locale>(value: Locale('es')),
                    child: Text(localize('button_es')),
                  ),
                ],
              ),
            ),
          ],
        ),
      ),
    );
  }
}
